////////////////////////////////////////////////////////////////////////
//
// 46-927 Data Structures, Algorithms and AI
//
// File: LookBackOption.cpp
//
// Student Name:        
// Date:          
// Comments:      Implementation of the CLookBackOption class
//
//                A class derived from CAbstractOption for
//                pricing Lookback Options
//
//                See LookBackOption.h
//
//                You must write the F() and Payoff() functions
//                (virtual functions in CAbstractOption).  In addition,
//                you must write MonteCarloPath().
//
//                double F(double s, double x) determines how the auxiliary process 
//                evolves over time -- s is the new stock price, x is the
//                old value of the auxiliary process.
//
//                double Payoff(double s, double x) computes the option payoff
//                in terms of the stock price (s) and the auxiliary process (x).
//
//                void MonteCarloPath(CNode* pathArray) fills the pathArray with
//                a random path from the PDAG.  Look at the nextPath() algorithm
//                described in the course notes to implement this function.
//                
//
//                See the Assignment Handout for more detail.
//
// 
////////////////////////////////////////////////////////////////////////


#include <iostream.h>
#include "LookBackOption.h"


//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CLookBackOption::CLookBackOption(int T, 
                                         double r, 
                                         double u, 
                                         double d, 
                                         double s_0):CAbstractOption(T, r, u, d, s_0) 
{
    //work handled by base class
    
}


CLookBackOption::CLookBackOption(int T, 
                                         double r, 
                                         double u, 
                                         double d, 
                                         double s_0,
                                         double strike):CAbstractOption(T, r, u, d, s_0) 
{
    //work handled by base class
    m_strike_price = strike;
}

CLookBackOption::~CLookBackOption()
{
}

void CLookBackOption::SetStrikePrice(double strike)
{
    m_strike_price = strike;
}

double CLookBackOption::F(double s, double x)
{
	if (s > x)
	{
		return s;
	}
	return x;
}

double CLookBackOption::Payoff(double s, double x, int t)
{
    double value = x - m_strike_price;
    if (value < 0) value=0.0;
    return(value);
}

